@@ -5,32 +5,34 @@ use warnings;
 
 package Version::Semantic;
 
-$Version::Semantic::VERSION = 'v1.1.0';
+$Version::Semantic::VERSION = 'v1.1.1';
 
 use overload '<=>' => 'compare_to', '""' => 'to_string';
 
+use PerlX::Maybe ();
+
 sub _croakf ( $@ );
 
 # <identifier characters>
-my $id = qr/(?: [0-9] | [a-zA-Z-] )+/x;
+my $id_re = qr/(?: [0-9] | [a-zA-Z-] )+/x;
 
 # <numeric identifier> (ok)
-my $num_id = qr/0 | [1-9] | [1-9] [0-9]+/x;
+my $num_id_re = qr/0 | [1-9] | [1-9] [0-9]+/x;
 
 # <alphanumeric identifier>
-my $alnum_id = qr/[a-zA-Z-] | [a-zA-Z-] $id | $id [a-zA-Z-] | $id [a-zA-Z-] $id/x;
+my $alnum_id_re = qr/[a-zA-Z-] | [a-zA-Z-] $id_re | $id_re [a-zA-Z-] | $id_re [a-zA-Z-] $id_re/x;
 
 # <build identifier>
-#my $build_id = qr/[0-9a-zA-Z-]+/;
-my $build_id = qr/$alnum_id | [0-9]+/x;
+#my $build_id_re = qr/[0-9a-zA-Z-]+/;
+my $build_id_re = qr/$alnum_id_re | [0-9]+/x;
 # <build> (ok)
-my $build = qr/$build_id (?: \. $build_id )*/x;
+my $build_re = qr/$build_id_re (?: \. $build_id_re )*/x;
 
 # <pre-release identifier>
-#my $pre_release_id = qr/$num_id | [0-9]* [a-zA-Z-] [0-9a-zA-Z-]*/x;
-my $pre_release_id = qr/$num_id | $alnum_id/x;
+#my $pre_release_id_re = qr/$num_id_re | [0-9]* [a-zA-Z-] [0-9a-zA-Z-]*/x;
+my $pre_release_id_re = qr/$num_id_re | $alnum_id_re/x;
 # <pre-release> (ok)
-my $pre_release = qr/$pre_release_id (?: \. $pre_release_id )*/x;
+my $pre_release_re = qr/$pre_release_id_re (?: \. $pre_release_id_re )*/x;
 
 # Use BNF terminology
 # https://semver.org/spec/v2.0.0.html#backusnaur-form-grammar-for-valid-semver-versions
@@ -50,12 +52,12 @@ sub has_build       { defined shift->{ build } }
   # the name of the last named capture group
   # <valid semver> (ok)
   my $semver = qr/
-    \A
-    (?<prefix> v)?
-    (?<major> $num_id) \. (?<minor> $num_id) \. (?<patch> $num_id)
-    (?: -  (?<pre_release> $pre_release) )?
-    (?: \+ (?<build> $build) )?
-    \z
+  \A
+  (?<prefix> v)?
+  (?<major> $num_id_re) \. (?<minor> $num_id_re) \. (?<patch> $num_id_re)
+  (?: -  (?<pre_release> $pre_release_re) )?
+  (?: \+ (?<build> $build_re) )?
+  \z
   /x;
 
   # Constructor as factory method
@@ -72,11 +74,11 @@ sub has_build       { defined shift->{ build } }
 {
   my %attrs = (
     prefix      => '[v]',
-    major       => $num_id,
-    minor       => $num_id,
-    patch       => $num_id,
-    pre_release => $pre_release,
-    build       => $build
+    major       => $num_id_re,
+    minor       => $num_id_re,
+    patch       => $num_id_re,
+    pre_release => $pre_release_re,
+    build       => $build_re
   );
 
   sub new {
@@ -117,12 +119,11 @@ sub has_build       { defined shift->{ build } }
 }
 
 {
-  # TRIAL is ok but TRIAL0 not!
   my $trial_pre_release = qr/\A ( TRIAL ) ( [0-9]* ) \z/x;
 
   sub increment {
     # Obvious strategies are major|minor|patch
-    my ( $self, $strategy ) = ( shift, shift );
+    my ( $self, $strategy, $pre_release ) = @_;
     $strategy //= 'patch';
 
     if ( $strategy eq 'trial' ) {
@@ -136,13 +137,11 @@ sub has_build       { defined shift->{ build } }
         _croakf "Cannot apply '%s' version incrementation strategy to non pre-release version '%s'", $strategy, $self
       }
     }
-    # FIXME: @_ should be validate: It has to have a even number of elements
-    # and the even elements have to be "pre_release" or "build"
-    return $self->new( patch => $self->patch + 1, @_ )
+    return $self->new( patch => $self->patch + 1, PerlX::Maybe::maybe pre_release => $pre_release )
       if $strategy eq 'patch';
-    return $self->new( minor => $self->minor + 1, patch => 0, @_ )
+    return $self->new( minor => $self->minor + 1, patch => 0, PerlX::Maybe::maybe pre_release => $pre_release )
       if $strategy eq 'minor';
-    return $self->new( major => $self->major + 1, minor => 0, patch => 0, @_ )
+    return $self->new( major => $self->major + 1, minor => 0, patch => 0, PerlX::Maybe::maybe pre_release => $pre_release )
       if $strategy eq 'major';
 
     _croakf "Version incrementation strategy '%s' is not implemented", $strategy
@@ -189,8 +188,8 @@ sub _compare_pre_release {
     my $ai = $a[ $i ];
     my $bi = $b[ $i ];
 
-    my $ai_is_num = $ai =~ m/\A (?: 0 | [1-9]\d* ) \z/x;
-    my $bi_is_num = $bi =~ m/\A (?: 0 | [1-9]\d* ) \z/x;
+    my $ai_is_num = $ai =~ m/\A $num_id_re \z/x;
+    my $bi_is_num = $bi =~ m/\A $num_id_re \z/x;
 
     # 11.4.1
     if ( $ai_is_num and $bi_is_num ) {
